@@ -118,7 +118,7 @@ class ProxyManager:
         return SessionProxy(self, success_criterion)
 
     async def proxy_session(self,
-                            fn: Callable[[Session, tuple], Optional[Any]],
+                            fn: Callable[[Session, asyncio.Event, tuple], Optional[Any]],
                             callback_async: Callable[[
                                 Optional[Any]], None] = lambda x: None,
                             exception_handle: Callable[[
@@ -153,7 +153,7 @@ class ProxyManager:
                     try:
                         timer.start()
                         result_future = self._loop.run_in_executor(
-                            self._executor, functools.partial(fn, session, *args))
+                            self._executor, functools.partial(fn, session, end_event, *args))
 
                         result = await result_future
                         timer.stop()
